==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/it.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fonte delle attività personali per %s",
    "Your feed URL is invalid" : "L'URL della fonte non è valido",
    "Activity feed for %1$s" : "Fonte delle attività per %1$s",
    "Activity feed" : "Fonte delle attività",
    "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
    "Settings have been updated." : "Le impostazioni sono state aggiornate.",
    "remote user" : "utente remoto",
    "Recent activity" : "Attività recente",
    "No activities" : "Nessuna attività",
    "More activities" : "Altre attività",
    "Daily activity summary for %s" : "Riepilogo giornaliero delle attività per %s",
    "_and %n more…_::_and %n more…_" : ["e %n altro…","e altri %n …","e altri %n …"],
    "All activities" : "Tutte le attività",
    "By others" : "Di altri",
    "By you" : "Tue",
    "Activity at %s" : "Attività su %s",
    "Hello %s" : "Ciao %s",
    "Hello %s," : "Ciao %s,",
    "There was some activity at %s" : "Attività registrata su %s",
    "_and %n more _::_and %n more _" : ["e %n altro ","e %n altri ","e %n altri "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puoi cambiare la frequenza di queste email o disattivarle nelle <a href=\"%s\">impostazioni</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puoi cambiare la frequenza di queste email o disattivarle nelle impostazioni: %s",
    "Mail" : "Posta",
    "Push" : "Push",
    "Activity" : "Attività",
    "Notifications" : "Notifiche",
    "This application enables people to view a log of activities about them, their files or other data." : "Questa applicazione consente agli utenti di visualizzare lo storico delle loro attività, dei loro file o di altri dati.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Questa applicazione consente agli utenti di visualizzare le possibili azioni correlate ai propri file o dati in Nextcloud.\n\t\tChiunque può configurare impostazioni specifiche per le proprie attività nelle impostazioni personali,\n\t\tper scegliere quale attività debba essere comunicata ai dispositivi mobili o inviata tramite email,\n\t\t o se inviare un rapporto giornaliero ogni mattina.\n\t\t Maggiori informazioni sono disponibili nella documentazione di Atttività.",
    "Send email" : "Invia email",
    "Send push notification" : "Invia notifica push",
    "Activity notification configuration" : "Configurazione notifica attività",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo di posta del tuo utente prima di poter ricevere le email di notifica.",
    "Send activity emails" : "Invia email delle attività",
    "As soon as possible" : "Non appena possibile",
    "Hourly" : "Ogni ora",
    "Daily" : "Giornalmente",
    "Weekly" : "Settimanalmente",
    "You commented" : "Hai commentato",
    "Message deleted by author" : "Messaggio eliminato dall'autore",
    "Open {filename}" : "Apri {filename}",
    "in {path}" : "in {path}",
    "Home" : "Home",
    "Could not load activities" : "Impossibile caricare le attività",
    "Loading activities" : "Caricamento delle attività",
    "This stream will show events like additions, changes & shares" : "Questo flusso mostrerà gli eventi come aggiunte, cambiamenti e condivisioni",
    "No activity yet" : "Ancora nessuna attività",
    "Loading more activities" : "Caricamento di altre attività",
    "No more activities." : "Nessun'altra attività.",
    "Could not enable RSS link" : "Impossibile attivare il collegamento RSS",
    "RSS link copied to clipboard" : "Collegamento RSS copiato negli appunti",
    "Could not copy the RSS link, please copy manually:" : "Impossibile copiare il collegamento RSS, copialo manualmente:",
    "Activity settings" : "Impostazioni delle attività",
    "Enable RSS feed" : "Abilita la fonte RSS",
    "RSS feed" : "Fonte RSS",
    "Copy RSS feed link" : "Copia il collegamento della fonte RSS",
    "Personal notification settings" : "Impostazioni di notifica personali",
    "Unable to load the activity list" : "Impossibile caricare l'elenco delle attività",
    "Choose for which activities you want to get an email or push notification." : "Scegli per quali attività desideri ricevere un'email o una notifica push.",
    "Choose for which activities you want to get a push notification." : "Scegli per quali attività desideri ricevere una notifica push.",
    "Notification" : "Notifica",
    "Enable notification emails" : "Abilita notifica tramite email",
    "Daily activity summary" : "Riepilogo dell'attività giornaliera",
    "Send daily activity summary in the morning" : "Invia un riepilogo giornaliero delle attività ogni mattina",
    "Default settings" : "Impostazioni predefinite",
    "Configure the default notification settings for new accounts." : "Configura le impostazioni predefinite di notifica per i nuovi account.",
    "Unable to save the settings" : "Impossibile salvare le impostazioni",
    "No more events to load" : "Non ci sono altri eventi da caricare"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/it.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fonte delle attività personali per %s",
    "Your feed URL is invalid" : "L'URL della fonte non è valido",
    "Activity feed for %1$s" : "Fonte delle attività per %1$s",
    "Activity feed" : "Fonte delle attività",
    "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
    "Settings have been updated." : "Le impostazioni sono state aggiornate.",
    "remote user" : "utente remoto",
    "Recent activity" : "Attività recente",
    "No activities" : "Nessuna attività",
    "More activities" : "Altre attività",
    "Daily activity summary for %s" : "Riepilogo giornaliero delle attività per %s",
    "_and %n more…_::_and %n more…_" : ["e %n altro…","e altri %n …","e altri %n …"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Puoi disabilitare il riassunto giornaliero via email nelle <a href=\"%s\">impostazioni</a>.",
    "You can disable daily digest emails in the settings: %s" : "Puoi disabilitare il riassunto giornaliero via email nelle impostazioni: %s",
    "All activities" : "Tutte le attività",
    "By others" : "Di altri",
    "By you" : "Tue",
    "Activity at %s" : "Attività su %s",
    "Hello %s" : "Ciao %s",
    "Hello %s," : "Ciao %s,",
    "There was some activity at %s" : "Attività registrata su %s",
    "_and %n more _::_and %n more _" : ["e %n altro ","e %n altri ","e %n altri "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puoi cambiare la frequenza di queste email o disattivarle nelle <a href=\"%s\">impostazioni</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puoi cambiare la frequenza di queste email o disattivarle nelle impostazioni: %s",
    "Mail" : "Posta",
    "Push" : "Push",
    "Activity" : "Attività",
    "Notifications" : "Notifiche",
    "This application enables people to view a log of activities about them, their files or other data." : "Questa applicazione consente agli utenti di visualizzare lo storico delle loro attività, dei loro file o di altri dati.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Questa applicazione consente agli utenti di visualizzare le possibili azioni correlate ai propri file o dati in Nextcloud.\n\t\tChiunque può configurare impostazioni specifiche per le proprie attività nelle impostazioni personali,\n\t\tper scegliere quale attività debba essere comunicata ai dispositivi mobili o inviata tramite email,\n\t\t o se inviare un rapporto giornaliero ogni mattina.\n\t\t Maggiori informazioni sono disponibili nella documentazione di Attività.",
    "Send email" : "Invia email",
    "Send push notification" : "Invia notifica push",
    "Activity notification configuration" : "Configurazione notifica attività",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo di posta del tuo utente prima di poter ricevere le email di notifica.",
    "Send activity emails" : "Invia email delle attività",
    "As soon as possible" : "Non appena possibile",
    "Hourly" : "Ogni ora",
    "Daily" : "Giornalmente",
    "Weekly" : "Settimanalmente",
    "You commented" : "Hai commentato",
    "Message deleted by author" : "Messaggio eliminato dall'autore",
    "Open {filename}" : "Apri {filename}",
    "in {path}" : "in {path}",
    "Home" : "Home",
    "Could not load activities" : "Impossibile caricare le attività",
    "Loading activities" : "Caricamento delle attività",
    "This stream will show events like additions, changes & shares" : "Questo flusso mostrerà gli eventi come aggiunte, cambiamenti e condivisioni",
    "No activity yet" : "Ancora nessuna attività",
    "Loading more activities" : "Caricamento di altre attività",
    "No more activities." : "Nessun'altra attività.",
    "Could not enable RSS link" : "Impossibile attivare il collegamento RSS",
    "RSS link copied to clipboard" : "Collegamento RSS copiato negli appunti",
    "Could not copy the RSS link, please copy manually:" : "Impossibile copiare il collegamento RSS, copialo manualmente:",
    "Activity settings" : "Impostazioni delle attività",
    "Enable RSS feed" : "Abilita la fonte RSS",
    "RSS feed" : "Fonte RSS",
    "Copy RSS feed link" : "Copia il collegamento della fonte RSS",
    "Personal notification settings" : "Impostazioni di notifica personali",
    "Unable to load the activity list" : "Impossibile caricare l'elenco delle attività",
    "Choose for which activities you want to get an email or push notification." : "Scegli per quali attività desideri ricevere un'email o una notifica push.",
    "Choose for which activities you want to get a push notification." : "Scegli per quali attività desideri ricevere una notifica push.",
    "Notification" : "Notifica",
    "Enable notification emails" : "Abilita notifica tramite email",
    "Daily activity summary" : "Riepilogo dell'attività giornaliera",
    "Send daily activity summary in the morning" : "Invia un riepilogo giornaliero delle attività ogni mattina",
    "Default settings" : "Impostazioni predefinite",
    "Configure the default notification settings for new accounts." : "Configura le impostazioni predefinite di notifica per i nuovi account.",
    "Unable to save the settings" : "Impossibile salvare le impostazioni",
    "No more events to load" : "Non ci sono altri eventi da caricare"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
